"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var EnvErrorType;
(function (EnvErrorType) {
    EnvErrorType[EnvErrorType["MISSING"] = 0] = "MISSING";
    EnvErrorType[EnvErrorType["WRONG_TYPE"] = 1] = "WRONG_TYPE";
})(EnvErrorType = exports.EnvErrorType || (exports.EnvErrorType = {}));
class EnvError extends Error {
    constructor(report) {
        super('Invalid or missing environment variables');
        this.report = report;
        this.name = 'EnvError';
        this.code = 'BAD_ENVIRONMENT_VARIABLES';
    }
    toString() {
        if (!this.report)
            return this.message;
        const errors = Object.entries(this.report).map(([key, { type, schemaValue, value }]) => formatError(key, type, schemaValue, value));
        return super.toString() + `\n    - ${errors.join('\n    - ')}\n`;
    }
}
exports.EnvError = EnvError;
function formatError(key, type, schemaValue, value) {
    switch (type) {
        case EnvErrorType.MISSING:
            return `Expected value for key '${key}'; none found`;
        case EnvErrorType.WRONG_TYPE:
            return schemaValue instanceof RegExp
                ? `Expected value for key '${key}' to match ${schemaValue}; got '${value}'`
                : `Expected value for key '${key}' of type ${schemaValue.name}; got '${value}'`;
    }
}
//# sourceMappingURL=EnvError.js.map