"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const EnvError_1 = require("./EnvError");
/**
 * Only allows exactly 'true' or 'false'
 */
const booleanRegExp = /^(true|false)$/;
/**
 * Only allows integers; crudely prevents values greater than MAX_SAFE_INTEGER.
 */
const numberRegExp = /^-?\d{1,15}$/;
function validate(schema, env) {
    const report = validateSchema(schema, env);
    if (report)
        throw new EnvError_1.EnvError(report);
    return true;
}
exports.validate = validate;
function validateSchema(schema, env) {
    const report = {};
    for (const [key, schemaValue] of Object.entries(schema)) {
        const value = env[key];
        if (!valueExists(value)) {
            report[key] = {
                type: EnvError_1.EnvErrorType.MISSING,
                schemaValue,
            };
        }
        else if (!typeMatches(schemaValue, value)) {
            report[key] = {
                type: EnvError_1.EnvErrorType.WRONG_TYPE,
                schemaValue,
                value,
            };
        }
    }
    return Object.values(report).some(value => value != null) ? report : null;
}
function valueExists(value) {
    return !(value === undefined || value === '');
}
function typeMatches(schemaValue, value) {
    switch (schemaValue) {
        case Boolean:
            return booleanRegExp.test(value);
        case Number:
            return numberRegExp.test(value);
        default:
            if (schemaValue instanceof RegExp)
                return schemaValue.test(value);
            return true;
    }
}
//# sourceMappingURL=validate.js.map